OC.L10N.register(
    "files",
    {
    "Added to favorites" : "お気に入りに追加",
    "Removed from favorites" : "お気に入りから削除",
    "You added {file} to your favorites" : "{file} をお気に入りに追加しました",
    "You removed {file} from your favorites" : "{file} をお気に入りから削除しました",
    "Favorites" : "お気に入り",
    "File changes" : "ファイル更新",
    "Created by {user}" : "{user} が作成しました",
    "Changed by {user}" : "{user} が更新しました",
    "Deleted by {user}" : "{user} が削除しました",
    "Restored by {user}" : "{user} が復元しました",
    "Renamed by {user}" : "{user} が作成しました",
    "Moved by {user}" : "{user} が移動しました",
    "\"remote account\"" : "\"リモートアカウント\"",
    "You created {file}" : "{file} を作成しました",
    "You created an encrypted file in {file}" : "{file} で暗号化ファイルを作成しました",
    "{user} created {file}" : "{user} が {file} を作成しました",
    "{user} created an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを作成しました",
    "{file} was created in a public folder" : "公開フォルダーに {file} が作成されました",
    "You changed {file}" : "{file} を更新しました",
    "You changed an encrypted file in {file}" : "{file}で暗号化されたファイルを変更しました。",
    "{user} changed {file}" : "{user} が {file} を更新しました",
    "{user} changed an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを変更しました",
    "You deleted {file}" : "{file} を削除しました",
    "You deleted an encrypted file in {file}" : "{file}で暗号化されたファイルを削除しました。",
    "{user} deleted {file}" : "{user} が {file} を削除しました",
    "{user} deleted an encrypted file in {file}" : "{user}が{file}で暗号化されたファイルを削除しました",
    "You restored {file}" : "{file} を復元しました",
    "{user} restored {file}" : "{user} が {file} を復元しました",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile}(非表示) の名前を {newfile}(非表示) に変更しました",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (非表示)の名前を{newfile}に変更しました",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile}の名前を{newfile}(非表示)に変更しました",
    "You renamed {oldfile} to {newfile}" : "{oldfile} を {newfile} に変更しました",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} は {oldfile}(非表示) の名前を {newfile}(非表示)  に変更しました",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} は {oldfile} (非表示) の名前を {newfile} に変更しました",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user}は{oldfile}を{newfile} (非表示)に名前変更しました",
    "{user} renamed {oldfile} to {newfile}" : "{user} が {oldfile} を{newfile} に変更しました",
    "You moved {oldfile} to {newfile}" : "{oldfile} を {newfile} に移動しました",
    "{user} moved {oldfile} to {newfile}" : "{user} が {oldfile} を {newfile} に移動しました",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
    "Files" : "ファイル",
    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーが<strong>変更</strong>されたとき",
    "A favorite file or folder has been <strong>changed</strong>" : "お気に入りのファイルまたはフォルダーが <strong>変更</strong>されたとき",
    "Failed to authorize" : "認証に失敗しました",
    "Invalid folder path" : "無効なフォルダーパス",
    "Folder not found" : "フォルダーが見つかりません",
    "The file cannot be found" : "ファイルが見つかりません",
    "The destination path does not exist: %1$s" : "宛先のパスが存在しません: %1$s",
    "You do not have permission to create a file at the specified location" : "指定された場所にファイルを作成する権限がありません",
    "The file could not be converted." : "ファイルを変換できませんでした。",
    "Could not get relative path to converted file" : "変換後のファイルへの相対パスを取得できませんでした",
    "Favorite files" : "お気に入りファイル",
    "No favorites" : "お気に入りなし",
    "More favorites" : "その他のお気に入り",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "Accept" : "承諾",
    "Reject" : "拒否",
    "Incoming ownership transfer from {user}" : "{user} からの所有権転送を受信",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} を承諾しますか？\n\n注意：承諾後の転送処理には最大 1 時間かかる場合があります。",
    "Ownership transfer denied" : "所有権の譲渡が拒否されました",
    "Your ownership transfer of {path} was denied by {user}." : "{path}の所有権の譲渡が{user}によって拒否されました。",
    "Ownership transfer failed" : "所有権の譲渡に失敗しました",
    "Your ownership transfer of {path} to {user} failed." : "{path}の{user}への所有権転送に失敗しました。",
    "The ownership transfer of {path} from {user} failed." : "{user} からの {path} の所有権転送に失敗しました。",
    "Ownership transfer done" : "所有権の譲渡が完了しました",
    "Your ownership transfer of {path} to {user} has completed." : "{user} への {path} の所有権転送が完了しました。",
    "The ownership transfer of {path} from {user} has completed." : "{user} からの {path} の所有権転送が完了しました。",
    "in %s" : "%s で",
    "Transferred from %1$s on %2$s" : "%1$sから%2$sに転送",
    "Files compatibility" : "ファイルの互換性",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ファイルをすべてのクライアントと同期できるようにするために、ファイル名を制限することを許可します。デフォルトではPOSIX（LinuxやmacOSなど）で有効なすべてのファイル名が許可されています。",
    "Enforce Windows compatibility" : "Windowsとの互換性を強制",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "予約名や特殊文字のような、Windowsシステムにおいて有効でないファイル名をブロックします。これは大文字、小文字の互換性を強制するものではありません。",
    "File Management" : "ファイル管理",
    "Home" : "ホーム",
    "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
    "Reload current directory" : "カレントディレクトリの再読み込み",
    "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
    "Current directory path" : "現在のディレクトリパス",
    "Your have used your space quota and cannot upload files anymore" : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
    "You do not have permission to upload or create files here." : "ここにファイルをアップロードまたは作成する権限がありません。",
    "Drag and drop files here to upload" : "ここにファイルをドラッグ＆ドロップしてアップロードする",
    "Favorite" : "お気に入り",
    "Back" : "戻る",
    "Toggle selection for file \"{displayName}\"" : "ファイル \"{displayName}\" の選択を切り替える",
    "Toggle selection for folder \"{displayName}\"" : "フォルダ \"{displayName}\" の選択を切り替える",
    "File is loading" : "ファイル読み込み中",
    "Folder is loading" : "フォルダーを読み込み中",
    "Filename" : "ファイル名",
    "Folder name" : "フォルダー名",
    "This node is unavailable" : "このノードは利用できません",
    "Another entry with the same name already exists." : "同じ名前の別のエントリがすでに存在しています。",
    "Invalid filename." : "無効なファイル名。",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
    "Rename file" : "ファイル名の変更",
    "Pending" : "保留中",
    "Unknown date" : "不明な日付",
    "Clear filter" : "フィルターをクリア",
    "Modified" : "更新日時",
    "Type" : "タイプ",
    "Active filters" : "有効なフィルター",
    "Remove filter" : "フィルターを削除",
    "Total rows summary" : "総行数のサマリー",
    "Toggle selection for all files and folders" : "すべてのファイルとフォルダの選択を切り替える",
    "Name" : "名前",
    "Size" : "サイズ",
    "\"{displayName}\" failed on some elements" : "いくつかの要素で \"{displayName}\" が失敗しました。",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
    "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
    "Actions" : "アクション",
    "(selected)" : "(選択済み)",
    "List of files and folders." : "ファイルとフォルダの一覧。",
    "You have used your space quota and cannot upload files anymore." : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
    "Column headers with buttons are sortable." : "ボタン付きの列ヘッダはソート可能です。",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
    "File not found" : "ファイルが見つかりません",
    "{count} selected" : "{count} 選択",
    "{usedQuotaByte} used" : "{usedQuotaByte} 使用されています",
    "{used} of {quota} used" : "{used} / {quota} 使用中",
    "{relative}% used" : "{relative}% 使用されています",
    "Could not refresh storage stats" : "ストレージの状態を更新できませんでした",
    "Your storage is full, files can not be updated or synced anymore!" : "ストレージは一杯です。ファイルの更新と同期はできません！",
    "Storage information" : "ストレージ情報",
    "Storage quota" : "ストレージのクォータ",
    "New folder" : "新しいフォルダー",
    "Create new folder" : "新しいフォルダーを作成",
    "This name is already in use." : "この名前は既に使用されています。",
    "Create" : "作成",
    "Fill template fields" : "テンプレートフィールドへの入力",
    "Submitting fields …" : "フィールドを送信中…",
    "Submit" : "提出する",
    "Choose a file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
    "Transfer" : "転送",
    "Transfer {path} to {userid}" : "{path} を {userid} に転送する",
    "Invalid path selected" : "無効なパスが選択されました",
    "Unknown error" : "不明なエラー",
    "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
    "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
    "Transfer ownership of a file or folder" : "ファイルまたはフォルダーの所有権を譲渡する",
    "Choose file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
    "Change" : "変更",
    "New owner" : "新しい所有者",
    "Keep {old}" : "{old} を保持",
    "Keep without extension" : "延長せずに保持",
    "Use {new}" : "{new}を使用する",
    "Remove extension" : "拡張子を削除",
    "Change file extension" : "ファイル拡張子を変更",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "ファイル拡張子を \"{old}\" から \"{new}\" に変更すると、ファイルが読み取れなくなる可能性があります。",
    "Removing the file extension \"{old}\" may render the file unreadable." : "ファイル拡張子 \"{old}\" を削除すると、ファイルが読み取れなくなる可能性があります。",
    "Adding the file extension \"{new}\" may render the file unreadable." : "ファイル拡張子 \"{new}\" を追加すると、ファイルが読み取れなくなる可能性があります。",
    "Do not show this dialog again." : "このダイアログを二度と表示しない。",
    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
    "Choose {file}" : "{file}を選択",
    "Share" : "共有",
    "Shared by link" : "URLリンクで共有中",
    "Shared" : "共有中",
    "Switch to list view" : "リスト表示へ切り替え",
    "Switch to grid view" : "グリッド表示へ切り替え",
    "The file could not be found" : "ファイルが見つかりませんでした",
    "Upload was cancelled by user" : "アップロードはユーザーによってキャンセルされました",
    "Not enough free space" : "十分な空き容量がありません",
    "Operation is blocked by access control" : "アクセス制御により操作がブロックされました",
    "Error during upload: {message}" : "アップロード中にエラーが発生しました: {message}",
    "Error during upload, status code {status}" : "アップロード中のエラー、ステータスコード {status}",
    "Unknown error during upload" : "不明なエラーがアップロード中に発生しました",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行された",
    "Loading current folder" : "現在のフォルダの読み込み中",
    "Retry" : "リトライ",
    "No files in here" : "ファイルがありません",
    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
    "Go back" : "戻る",
    "Filter file names …" : "ファイルネームフィルター…",
    "Views" : "表示",
    "Files settings" : "ファイルの設定",
    "Your files" : "あなたのファイル",
    "Open in files" : "ファイルで開く",
    "File cannot be accessed" : "ファイルにアクセスできません",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ファイルが見つからないか、あなたがそれを表示する権限を持っていない可能性があります。送信者に共有するように依頼してください。",
    "Clipboard is not available" : "クリップボードは利用できません",
    "WebDAV URL copied to clipboard" : "WebDAVのURLがクリップボードにコピーされました",
    "Sort favorites first" : "お気に入りを最初に並べる",
    "Sort folders before files" : "ファイルよりもフォルダを先に並べ替えます",
    "Show hidden files" : "隠しファイルを表示",
    "Crop image previews" : "プレビュー画像を切り抜く",
    "Enable the grid view" : "グリッド表示を有効にする",
    "Enable folder tree" : "フォルダーツリーを有効にする",
    "Additional settings" : "追加設定",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "クリップボードにコピー",
    "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FAを有効にしている場合は、ここをクリックして新しいアプリのパスワードを作成し、使用する必要があります。",
    "Warnings" : "警告",
    "Prevent warning dialogs from open or reenable them." : "警告ダイアログが開かないようにするか、再度有効にする。",
    "Show a warning dialog when changing a file extension." : "ファイルの拡張子を変更する際に、警告ダイアログを表示する。",
    "Keyboard shortcuts" : "キーボードショートカット",
    "Speed up your Files experience with these quick shortcuts." : "これらのショートカットでファイルの取り扱いを高速化します",
    "Open the actions menu for a file" : "ファイルのアクションメニューを開く",
    "Rename a file" : "ファイル名を変更",
    "Delete a file" : "ファイルを削除",
    "Favorite or remove a file from favorites" : "ファイルをお気に入りから追加または削除",
    "Manage tags for a file" : "ファイルのタグを管理する",
    "Selection" : "選択",
    "Select all files" : "全てのファイルを選択",
    "Deselect all files" : "全てのファイルの選択を解除",
    "Select or deselect a file" : "ファイルを選択または選択を解除",
    "Select a range of files" : "範囲内のファイルを選択",
    "Navigation" : "ナビゲーション",
    "Navigate to the parent folder" : "親フォルダーに移動",
    "Navigate to the file above" : "上のファイルに移動",
    "Navigate to the file below" : "下のファイルに移動",
    "Navigate to the file on the left (in grid mode)" : "左のファイルに移動（グリッドモード）",
    "Navigate to the file on the right (in grid mode)" : "右のファイルに移動（グリッドモード）",
    "View" : "表示",
    "Toggle the grid view" : "グリッドビューを切り替え",
    "Open the sidebar for a file" : "ファイルのサイドバーを開く",
    "Show those shortcuts" : "これらのショートカットを表示する",
    "You" : "自分",
    "Shared multiple times with different people" : "異なる人と複数回共有",
    "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
    "Owner" : "作成者",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "Tags" : "タグ",
    "Blank" : "ブランク",
    "Unable to create new file from template" : "テンプレートから新しいファイルを作成できません",
    "Pick a template for {name}" : "{name} のテンプレートを選択してください",
    "Create a new file with the selected template" : "選択したテンプレートを使用して新しいファイルを作成します",
    "Creating file" : "ファイル作成",
    "Save as {displayName}" : "{displayName}として保存",
    "Save as …" : "保存…",
    "Converting files …" : "ファイルの変換…",
    "Failed to convert files: {message}" : "ファイルの変換に失敗しました: {message}",
    "All files failed to be converted" : "すべてのファイルの変換に失敗しました",
    "One file could not be converted: {message}" : "1つのファイルが変換できませんでした: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["%n個のファイルが変換できませんでした"],
    "_One file successfully converted_::_%n files successfully converted_" : ["%n個のファイルの変換に成功しました"],
    "Files successfully converted" : "ファイルは正常に変換されました",
    "Failed to convert files" : "ファイルの変換に失敗しました",
    "Converting file …" : "ファイルの変換…",
    "File successfully converted" : "ファイルは正常に変換されました",
    "Failed to convert file: {message}" : "ファイルの変換に失敗しました: {message}",
    "Failed to convert file" : "ファイルの変換に失敗しました",
    "Deletion cancelled" : "削除はキャンセルされました",
    "Leave this share" : "この共有から抜ける",
    "Leave these shares" : "これらの共有から抜ける",
    "Disconnect storage" : "ストレージを切断する",
    "Disconnect storages" : "ストレージを切断する",
    "Delete permanently" : "完全に削除する",
    "Delete and unshare" : "削除して共有を解除",
    "Delete file" : "ファイルを削除",
    "Delete files" : "ファイルの削除",
    "Delete folder" : "フォルダーを削除",
    "Delete folders" : "フォルダを削除",
    "Delete" : "削除",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}アイテムを完全に削除しようとしています"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["あなたは {count} 個のアイテムを削除しようとしています"],
    "Confirm deletion" : "削除の確認",
    "Cancel" : "キャンセル",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
    "(copy)" : "(copy)",
    "(copy %n)" : "(copy %n)",
    "Move cancelled" : "移動はキャンセルされました",
    "A file or folder with that name already exists in this folder" : "その名前のファイルまたはフォルダが、このフォルダに既に存在します",
    "The files are locked" : "ファイルはロックされています",
    "The file does not exist anymore" : "ファイルはもう存在しません",
    "Choose destination" : "移動先を選択",
    "Copy to {target}" : "{target} にコピー",
    "Copy" : "コピー",
    "Move to {target}" : "{target} に移動",
    "Move" : "移動",
    "Move or copy operation failed" : "移動またはコピー操作は失敗しました",
    "Move or copy" : "移動またはコピー",
    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"の移動またはコピーをキャンセルしました。",
    "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
    "Open folder {displayName}" : "フォルダ {displayName} を開く",
    "Open in Files" : "ファイルアプリで開く",
    "Open file locally" : "ローカルでファイルを開く",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "ファイルがデバイス上で開くはずです。開かない場合は、デスクトップアプリがインストールされているかご確認ください。",
    "Retry and close" : "再試行して閉じる",
    "Open online" : "オンラインで開く",
    "Failed to redirect to client" : "クライアントへリダイレクトできませんでした",
    "Open locally" : "ローカルで開く",
    "Rename" : "名前の変更",
    "Open details" : "詳細を開く",
    "View in folder" : "フォルダー内で表示",
    "Today" : "今日",
    "Last 7 days" : "7日以内",
    "Last 30 days" : "30日以内",
    "This year ({year})" : "今年 ({year})",
    "Last year ({year})" : "去年 ({year})",
    "Documents" : "ドキュメント",
    "Spreadsheets" : "スプレッドシート",
    "Presentations" : "プレゼンテーション",
    "PDFs" : "PDF",
    "Folders" : "フォルダー",
    "Audio" : "オーディオ",
    "Photos and images" : "写真と画像",
    "Videos" : "動画",
    "New folder creation cancelled" : "新しいフォルダーの作成がキャンセルされました",
    "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成しました",
    "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
    "Create templates folder" : "テンプレートフォルダーの作成",
    "Templates" : "テンプレート",
    "New template folder" : "新しいテンプレートフォルダ",
    "In folder" : "フォルダ内",
    "Search in folder: {folder}" : "フォルダ内を検索: {folder}",
    "One of the dropped files could not be processed" : "ドロップされたファイルの1つが処理できませんでした",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "お使いのブラウザはファイルシステムAPIをサポートしていません。ディレクトリはアップロードされません",
    "No files to upload" : "アップロードするファイルがありません",
    "Unable to create the directory {directory}" : "ディレクトリ {directory} を作成できません",
    "Some files could not be uploaded" : "いくつかのファイルがアップロードできませんでした",
    "Files uploaded successfully" : "ファイルが正常にアップロードされました",
    "No files to process" : "処理するファイルがありません",
    "Some files could not be copied" : "いくつかのファイルがコピーできません",
    "Some files could not be moved" : "いくつかのファイルが移動できません",
    "Files copied successfully" : "ファイルが正常にコピーされました",
    "Files moved successfully" : "ファイルの移動に成功しました",
    "Conflicts resolution skipped" : "コンフリクトの解決はスキップされました",
    "Upload cancelled" : "アップロードはキャンセルされました",
    "This operation is forbidden" : "この操作は禁止されています",
    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
    "Unexpected error: {error}" : "予期せぬエラー: {error}",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} フォルダ"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ファイル"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ファイルと {folderCount} フォルダ"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ファイルと 1 フォルダ"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} ファイルと {folderCount} フォルダ",
    "Filename must not be empty." : "ファイル名は空白にできません。",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\"はファイル名には使用できません。",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\"は予約名であり、ファイル名には使用できません。",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" は許可されたファイルタイプではありません。",
    "Filenames must not end with \"{extension}\"." : "ファイル名は \"{extension}\"で終了できません。",
    "List of favorite files and folders." : "お気に入りのファイルやフォルダーの一覧",
    "No favorites yet" : "まだお気に入りはありません",
    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
    "All files" : "すべてのファイル",
    "List of your files and folders." : "ファイルやフォルダーの一覧",
    "All folders" : "全てのフォルダー",
    "Personal files" : "個人ファイル",
    "List of your files and folders that are not shared." : "共有されていないファイルやフォルダの一覧。",
    "No personal files found" : "個人ファイルは見つかりませんでした",
    "Files that are not shared will show up here." : "共有されていないファイルは、ここに表示されます。",
    "Recent" : "最新",
    "List of recently modified files and folders." : "最近変更されたファイルとフォルダーのリスト",
    "No recently modified files" : "最近更新されたファイルはありません",
    "Files and folders you recently modified will show up here." : "最近変更したファイルやフォルダーがここに表示されます。",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Select all" : "すべて選択",
    "Upload too large" : "アップロードには大きすぎます。",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
    "File could not be found" : "ファイルを見つけられませんでした",
    "Download" : "ダウンロード",
    "Show list view" : "リストビューで表示",
    "Show grid view" : "グリッドビューで表示",
    "Close" : "閉じる",
    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
    "This will stop your current uploads." : "現在のアップロードが停止されます。",
    "Upload cancelled." : "アップロードはキャンセルされました。",
    "Processing files …" : "ファイルの処理中...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリであるか、または0バイトのため {filename} をアップロードできません",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
    "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
    "An unknown error has occurred" : "不明なエラーが発生しました",
    "File could not be uploaded" : "ファイルをアップロードできませんでした",
    "Uploading …" : "アップロード中...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "アップロード中… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
    "Uploading that item is not supported" : "そのアイテムのアップロードに対応していません",
    "Error when assembling chunks, status code {status}" : "チャンクを組み立てる際のエラー、ステータスコード{status}",
    "Choose target folder" : "ターゲットフォルダーを選択",
    "Set reminder" : "リマインダーを設定",
    "Edit locally" : "ローカルで編集",
    "Open" : "開く",
    "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
    "Details" : "詳細",
    "Please select tag(s) to add to the selection" : "選択項目に付与するタグを選択してください",
    "Apply tag(s) to selection" : "選択項目にタグを適用",
    "Select directory \"{dirName}\"" : "ディレクトリを選択: \"{dirName}\"",
    "Select file \"{fileName}\"" : "ファイルを選択: \"{fileName}\"",
    "Unable to determine date" : "更新日不明",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "copy" : "コピー",
    "Could not copy \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"をコピーできませんでした",
    "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
    "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
    "{newName} already exists" : "{newName} はすでに存在します",
    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できません",
    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できません",
    "Could not fetch file details \"{file}\"" : "\"{file}\" の詳細が取得できませんでした",
    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
    "Enter more than two characters to search in other folders" : "他のフォルダーで検索するには、3文字以上を入力してください",
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "_%n file_::_%n files_" : ["%n 個のファイル"],
    "{dirs} and {files}" : "{dirs} と {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
    "You do not have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
    "New" : "新規作成",
    "New file/folder menu" : "新規ファイル/フォルダメニュー",
    "Select file range" : "ファイルを範囲選択",
    "{used}%" : "{used}%",
    "{used} used" : "{used} 使用中",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はできません！",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "グループフォルダー ”{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部ストレージ \"{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
    "Your storage is full, files cannot be updated or synced anymore!" : "ストレージがいっぱいで、ファイルを更新または同期できなくなりました。",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} のストレージがほぼ一杯 ({usedSpacePercent}％) です",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "グループフォルダー \"{mountPoint}\" がほぼいっぱい ({usedSpacePercent}％) です。",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部ストレージ \"{mountPoint}\" はほぼいっぱい ({usedSpacePercent}％) です",
    "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "ダイレクトリンクがコピーされました（このファイルやフォルダにアクセスできる人にのみ機能します）",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n バイト"],
    "Favorited" : "お気に入り済",
    "Copy direct link (only works for people who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダにアクセスできる人にのみ機能します)",
    "Upload file" : "ファイルをアップロード",
    "Not favorited" : "お気に入りではありません",
    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
    "You don't have permission to upload or create files here." : "ここにファイルをアップロードまたは作成する権限がありません。",
    "Storage informations" : "ストレージ情報",
    "Choose file" : "ファイルを選択",
    "Go to the previous folder" : "前のフォルダへ移動",
    "Open the files app settings" : "ファイルアプリの設定を開く",
    "Unable to change the favourite state of the file" : "ファイルのお気に入りの状態を変更できません",
    "Edit file locally" : "ファイルをローカルで編集",
    "Edit online" : "オンラインで編集",
    "Create new templates folder" : "新しいテンプレートフォルダーを作成",
    "List of favorites files and folders." : "お気に入りのファイルやフォルダーの一覧",
    "Personal Files" : "個人ファイル",
    "Text file" : "テキストファイル",
    "New text file.txt" : "新規のテキストファイル作成",
    "Favored" : "好評",
    "Favor" : "好意的",
    "Not favored" : "好ましくない",
    "Submitting fields…" : "フィールドを送信中…",
    "Filter filenames…" : "ファイルネームフィルター…",
    "{count} files could not be converted" : "{count}個のファイルが変換できませんでした",
    "{count} files successfully converted" : "{count}個のファイルの変換に成功しました"
},
"nplurals=1; plural=0;");
